
Installation
============

Download and run the bootstrap program where you want Transmogrify to live:

mkdir -p /var/code/transmogrify
cd /var/code/transmogrify
curl https://raw.github.com/callowayproject/Transmogrify/master/bootstrap.py | python

That creates a python ``virtualenv`` and installs